@@ -1,5 +1,5 @@
 package Selenium::Remote::Driver;
-$Selenium::Remote::Driver::VERSION = '0.1801'; # TRIAL
+$Selenium::Remote::Driver::VERSION = '0.19'; # TRIAL
 # ABSTRACT: Perl Client for Selenium Remote Driver
 
 use Moo;
@@ -140,7 +140,21 @@ has 'proxy' => (
 
 has 'extra_capabilities' => (
     is      => 'rw',
-    default => sub { {} },
+    default => sub { {} }
+);
+
+has 'firefox_profile' => (
+    is => 'rw',
+    coerce => sub {
+        my $profile = shift;
+        unless (Scalar::Util::blessed($profile)
+          && $profile->isa('Selenium::Remote::Driver::Firefox::Profile')) {
+            croak "firefox_profile should be a Selenium::Remote::Driver::Firefox::Profile\n";
+        }
+
+        return $profile->_encode;
+    },
+    predicate => 'has_firefox_profile'
 );
 
 sub BUILD {
@@ -221,6 +235,11 @@ sub new_session {
         $args->{desiredCapabilities}->{proxy} = $self->proxy;
     }
 
+    if ($args->{desiredCapabilities}->{browserName} =~ /firefox/i
+        && $self->has_firefox_profile) {
+        $args->{desiredCapabilities}->{firefox_profile} = $self->firefox_profile;
+    }
+
     # command => 'newSession' to fool the tests of commands implemented
     # TODO: rewrite the testing better, this is so fragile.
     my $resp = $self->remote_conn->request(
@@ -1020,7 +1039,7 @@ Selenium::Remote::Driver - Perl Client for Selenium Remote Driver
 
 =head1 VERSION
 
-version 0.1801
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -2017,26 +2036,28 @@ To conveniently write the screenshot to a file, see L<capture_screenshot()>.
 
 =head1 SEE ALSO
 
-For more information about Selenium , visit the website at
-L<http://code.google.com/p/selenium/>.
+Please see those modules/websites for more information related to this module.
 
-Also checkout project's wiki page at
-L<https://github.com/gempesaw/Selenium-Remote-Driver/wiki>.
+=over 4
+
+=item *
+
+L<http://code.google.com/p/selenium/|http://code.google.com/p/selenium/>
+
+=item *
+
+L<https://github.com/gempesaw/Selenium-Remote-Driver/wiki|https://github.com/gempesaw/Selenium-Remote-Driver/wiki>
+
+=back
 
 =head1 BUGS
 
-The Selenium issue tracking system is available online at
-L<http://github.com/gempesaw/Selenium-Remote-Driver/issues>.
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/gempesaw/Selenium-Remote-Driver/issues
 
-=head1 SEE ALSO
-
-For more information about Selenium , visit the website at
-L<http://code.google.com/p/selenium/>.
-
-=head1 BUGS
-
-The Selenium issue tracking system is available online at
-L<http://github.com/gempesaw/Selenium-Remote-Driver/issues>.
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHORS
 
