@@ -1,5 +1,5 @@
 package Selenium::Remote::RemoteConnection;
-$Selenium::Remote::RemoteConnection::VERSION = '0.1801'; # TRIAL
+$Selenium::Remote::RemoteConnection::VERSION = '0.19'; # TRIAL
 #ABSTRACT: Connect to a selenium server
 
 use Moo;
@@ -159,17 +159,28 @@ Selenium::Remote::RemoteConnection - Connect to a selenium server
 
 =head1 VERSION
 
-version 0.1801
+version 0.19
 
 =head1 SEE ALSO
 
-For more information about Selenium , visit the website at
-L<http://code.google.com/p/selenium/>.
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Selenium::Remote::Driver|Selenium::Remote::Driver>
+
+=back
 
 =head1 BUGS
 
-The Selenium issue tracking system is available online at
-L<http://github.com/gempesaw/Selenium-Remote-Driver/issues>.
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/gempesaw/Selenium-Remote-Driver/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHORS
 
